
####################################################################
####################################################################
###################                             ####################
###################      TREE GROWTH PAPER      ####################
###################                             ####################
####################################################################
####################################################################

# Neighborhood analysis : 
# calculation of competition indices 
# written by Clara Zemp, 2018

library(data.table)

#deleting all objects
rm(list=ls())

# set working directory 
setwd("C:/CRC990-B11/data/trees")


#####################################################################################
# import data 

# distances to oil palms and trees
tr.utm <- fread("tr.utm.csv") # tree distance of oil palm and fence 
tr.nn <- fread('tr.nn.csv') # pairwise distance between trees 

# tree size and diversity 
#str.B11plots    <- fread("C:/CRC990-B11/data/str.B11plots.csv") 
tree.plots <- fread("B11.tree.plots.csv") # for each tree invidual
#stat.tree.plots <- fread("stat.tree.plots.csv") # for each plot
#tree.merge <- fread("B11.tree.merge.csv")

tree_sp = unique(tree.plots$Species)

#####################################################################################
# get species-specific competition indeces 


# d_neighbors = 9 # choose here the threshold to define neighborhood (in m)
for (d_neighbors in seq(3,9,2)){ # check multiple thresholds
  print(d_neighbors)
  
# get tree IDs in a vector 
TreeIDs = tree.plots$TreeID 

# initialize 
neighborhood = data.frame(matrix(ncol=17, nrow=length(TreeIDs)))  
names(neighborhood ) <- c("TreeID", tree_sp,"all","consp","heterosp","R_neighbors",
                          paste("N",tree_sp,sep=""))
#                       "N_total_neighbors","N_dead_neighbors","N_alive_neighbors",
#                       "Mean_BA_neighbors","Max_BA_neighbors","Mean_height_neighbors","Max_height_neighbors")

k=1
for (i in TreeIDs) {
  
  # extract neighboring trees
  neighbors = tr.nn[which(i_ID==i & (d<d_neighbors))]$j_ID
  
  # get total number of tree individuals in neighborhood
  N_total_neighbors = length(neighbors) # total number of neighbors
  N_alive_neighbors = length(tree.plots[which(TreeID %in% neighbors & Survival.2017==1)]$TreeID) # number of living trees in neighborhood
  N_dead_neighbors = length(tree.plots[which(TreeID %in% neighbors & Survival.2017==1)]$TreeID) # number of dead trees in neighborhood
  
  # get number of hetero-specific species in neighborhood
  Sp_i = tree.plots[i]$Species # species of focal tree
  Sp_neighbors = unique(tree.plots[which(TreeID %in% neighbors & Survival.2017==1 & Species!=Sp_i)]$Species) # list of species in neighborhood that are different from focal species 
  R_neighbors = length(Sp_neighbors != tree.plots[i]$Species) # species richness 
  
  # get composition in the neighborhood
  Sp_neighbors_all = tree.plots[which(TreeID %in% neighbors & Survival.2017==1)]$Species # species composition in neighborhood 
  N = data.frame(matrix(ncol=6, nrow=1))  
  names(N) <- tree_sp
  r=1
  for (s in tree_sp){
  N_s = length(which(Sp_neighbors_all == s)) # number of individuals from species s
  N[r] <- N_s
  r=r+1 
  }
  
  ## get diversity indices 
  
  # -- get proportions of species 
  #diversity_neighbors = R_neighbors / N_alive_neighbors
  
  # -- get shanon diversity index 
  #h = matrix(nrow=R_neighbors,ncol=1)
  #for (s in R_neighbors){
  #   N_alive_neighbors_s = nrow(tree.plots[TreeID %in% neighbors & Survival.2017==1 & Species==Sp_neighbors[s]])# nb of trees in neighborhood that belong to species i
  #   h[s] = (N_alive_neighbors_s /N_alive_neighbors)*log(N_alive_neighbors_s /N_alive_neighbors) # term in shanon diversity index 
  # }
  #H_neighbors = - sum(h, na.rm=T) # shannon diversity index 
  
  ## extract size of all trees in neighborhood
  
  #BA_neighbors = tree.plots[which(TreeID %in% neighbors),]$BA.2016
  #Height_neighbors = tree.plots[which(TreeID %in% neighbors),]$Height_vertical.2016
  
  ## get mean and max size of trees in neighborhood
  
  #Mean_BA_neighbors = mean(BA_neighbors,na.rm="True") # mean basal area of neighbors
  #Max_BA_neighbors = max(BA_neighbors,na.rm="True") # max basal area of neighbors
  #Mean_height_neighbors = mean(Height_neighbors,na.rm="True") # mean height of neighbors
  #Max_height_neighbors = max(Height_neighbors,na.rm="True") # max height of neighbors
  
  ## get species-specific competition index (after Zhao et al. 2016)
  s=1
  CI = matrix(ncol=1, nrow=length(tree_sp) )
  for (sp in tree_sp){ # for each species sp
    
    # get all individuals in the neighborhood that belong to that species
    j_sp = tree.plots[TreeID %in% neighbors & Survival.2017==1 & Species ==sp]$TreeID 
    
    # initialize 
    CI_value = matrix(ncol=1, nrow=length(j_sp) )
    
    if (length(j_sp)>0){
    for (j in length(j_sp)){ # for each tree individual in the neighborhood that belong to species sp
      
      d_ij = tr.nn[i_ID==i & j_ID==j_sp[j]]$d # get the distance 
      
      # get competition index 1:  diameter / distance  (if 25 m radius) (Zhao et al. 2006)
      #CI_value[j] = tree.plots[TreeID == j_sp[j]]$Diameter.2016/d_ij
      
      # get competition index 2 :  diameter / (diameter target * distance ) (if 5 m radius) (VonOheimb et al . 2011)
      CI_value[j] = tree.plots[TreeID == j_sp[j]]$Diameter.2017/
        (tree.plots[TreeID == i]$Diameter.2017 * (d_ij+1) )
    }}
    
    CI[s] <- sum(CI_value,na.rm=T) # sum over all individuals in the neighborhood that belong to species sp
    s=s+1
  }
  
  # fill in the data frame
  neighborhood[k,]$TreeID <- i
  neighborhood[k,2:7] <- t(CI)
  #  neighborhood[k,]$N_total_neighbors <- N_total_neighbors
  #  neighborhood[k,]$N_dead_neighbors <- N_dead_neighbors
  # neighborhood[k,]$N_alive_neighbors <- N_alive_neighbors
  #neighborhood[k,]$H_neighbors <- H_neighbors
  neighborhood[k,]$R_neighbors <- R_neighbors
  # neighborhood[k,]$Mean_BA_neighbors <- Mean_BA_neighbors
  # neighborhood[k,]$Max_BA_neighbors <- Max_BA_neighbors
  # neighborhood[k,]$Mean_height_neighbors <- Mean_height_neighbors
  # neighborhood[k,]$Max_height_neighbors <- Max_height_neighbors
  neighborhood[k,12:17] <- N
  
  k=k+1
  #print(k)
  }

## Get over-all competition index 
ci1 = which(names(neighborhood)=="petai") # get the column number where CI of individual species start 
k=1
for (i in TreeIDs) {
   neighborhood[k,]$all <- rowSums(neighborhood[k,ci1:(ci1+5)]) # competition index independent from species ID
   k=k+1}

# save files 
#write.csv(neighborhood, file = paste("neighborhood_2017.",d_neighbors,"m.csv",sep=""),row.names=TRUE, na="")


##########################################################################################
##########################################################################################
# get hetero-specific and con-specific competition index 

#neighborhood <- fread("neighborhood_2017.8m.csv")

neighborhood$all = as.numeric(neighborhood$all)
neighborhood$consp = as.numeric(neighborhood$consp)
neighborhood$heterosp = as.numeric(neighborhood$heterosp)


for (id in TreeIDs){
  #print(id)
  sp <- tree.plots[TreeID==id]$Species # get the tree species
  
  ind = which(neighborhood$TreeID==id) # find index in the matrix 
  neighborhood[ind,]$all <- sum(neighborhood[ind,2:7])# get the sum of all CI
  #neighborhood[ind,]$all <- sum(neighborhood[ind,"petai":"sungkai"])# get the sum of all CI
  
  C = which(names(neighborhood) == sp) # get column of CI for that species
  neighborhood[ind,]$consp <- neighborhood[ind,as.numeric(C)]
  neighborhood[ind,]$heterosp <- (neighborhood[ind,]$all - neighborhood[ind,]$consp)
  }

# save files 
#write.csv(neighborhood, file = "neighborhood_2017.8m.csv",row.names=TRUE, na="")
write.csv(neighborhood, file = paste("neighborhood_2017.",d_neighbors,"m.csv",sep=""),row.names=TRUE, na="")

}
