
####################################################################
####################################################################
###################                             ####################
###################      TREE GROWTH PAPER      ####################
###################                             ####################
####################################################################
####################################################################

# script to write position of trees, distance to oil palms (cut and alive) and tree neightbors 
# Script initially written by Anne Gérard (2016), modified by Clara Zemp (05/2018) 


library(maptools);library(calibrate); library(splancs); library(spatstat); library(plyr)
library(sfsmisc); library(cluster); 
library(spatstat); library(plyr)


rm(list=ls())
#setwd("C:/Users/Anne/Promotion/Ergebnisse/tbl")
setwd("C:/CRC990-B11/shared_doc_data/B11_data_from_Anne/Paper_TreeGrowth/Data")


###################################################################################################################
###############################         WRITE TABLES        #################################################
#######################################################################################################

########## read data 

tr.utm <- read.csv("20160104_tree_coord.csv", header=TRUE, sep=",") # tree coordinates 
poly <- read.csv("Plot_polygons.csv", header=TRUE, sep=",") # plots coordiantes 
poly$Plot_ID <- as.factor(poly$Plot_ID)
op <- read.csv("OP_coordinates.csv", header=TRUE, sep=",") # oil palms coordinates 

########## projection of x and y-coordinates ###########
coordinates(tr.utm) <- c("X","Y")
proj4string(tr.utm) <- CRS("+proj=utm +zone=48 +ellps=WGS84")
coordinates(poly) <- c("X","Y")
proj4string(poly) <- CRS("+proj=utm +zone=48 +ellps=WGS84")
coordinates(op) <- c("X","Y")
proj4string(op) <- CRS("+proj=utm +zone=48 +ellps=WGS84")

tr.utm$Plot_ID <- as.factor(tr.utm$Plot_ID)
op$Plot_ID <- as.factor(op$Plot_ID)
op$Palm_ID <- as.factor(op$Palm_ID)

#### the required format for spatstat analyses
tr.utm.ppp <- as.ppp.SpatialPointsDataFrame(tr.utm)

op.cut <- subset(op, op$cut=="Y")
op.al <- subset(op, op$cut=="N"| op$cut=="out")#
#op.out <- subset(op, op$cut=="out")
op.ppp.cut <- as.ppp.SpatialPointsDataFrame(op.cut)
op.ppp.al <- as.ppp.SpatialPointsDataFrame(op.al)
#op.ppp.out <- as.ppp.SpatialPointsDataFrame(op.out)

################ crown projection around each oil palm
op$LeafArea_EW <- op$LeafArea_EW/2 ## half axes are needed, we measured diameter
op$LeafArea_NS <- op$LeafArea_NS/2 ## half axes are needed, we measured diameter
op$Palm_ID <- as.character(op$Palm_ID)
op_al <- subset(op, op$cut=="N") ### only the ones that were not cut

############### Distance to plot border
point <- as.data.frame(cbind(tr.utm$Plot_ID, tr.utm$Tree_ID, tr.utm$X, tr.utm$Y))
names(point) <- c("Plot_ID", "Tree_ID", "X", "Y")
polygon1 <- as.data.frame(cbind(poly$Plot_ID, poly$X, poly$Y))
names(polygon1) <- c("Plot_ID", "X", "Y")
dist <- vector()

for (i in 1:length(levels(tr.utm$Plot_ID))) {
  polygon1.test <- cbind(polygon1$X[polygon1$Plot_ID==i], polygon1$Y[polygon1$Plot_ID==i])
  point.sub <- subset(point, point$Plot_ID==i)
  
  for (j in 1:length(point.sub$Tree_ID)) {
    point.test <- cbind(point.sub$X[j], point.sub$Y[j])
    
    temp <- nearestPointOnLine(polygon1.test,point.test)
    dist.temp <- spDistsN1(point.test, temp, longlat = FALSE)
    dist <- c(dist, dist.temp) 
  }}

####################################################################################
dist.poly <- as.data.frame(cbind(point$Tree_ID, dist)) #############################
names(dist.poly) <- c("Tree_ID", "dEdge") ##########################################
tr.utm <- merge(tr.utm, dist.poly, by="Tree_ID") ###################################
####################################################################################

# get the distance to nearest oil palm (living and dead) and to each tree
# max distance is 60 m to make sure that observations are not in another plot
# but the actual distance should not exceed 10m (for living oil palm)

############## All living oil palms of all trees in 60 m distance
##########################################################################
op.al.nn <- as.data.frame(crosspairs(tr.utm.ppp, op.ppp.al, rmax=60)) ####
op.al.nn$i_ID <- tr.utm$Tree_ID[op.al.nn$i] ##############################
op.al.nn$j_ID <- op.al$Palm_ID[op.al.nn$j] ###############################
op.al.nn <- op.al.nn[order(op.al.nn$i_ID, op.al.nn$d),] ##################
op.al.min <- ddply(op.al.nn, "i_ID", head, 1) ############################
op.al.min1 <- cbind(op.al.min[,10:9]) ####################################
names(op.al.min1) <- c("Tree_ID", "dOPal") ###############################
tr.utm <- merge(tr.utm, op.al.min1, by="Tree_ID") ########################
##########################################################################


############## All cut oil palms of all trees in 200 m distance
#(200 m to be sure that there is no NA is the data)
##########################################################################
op.cut.nn <- as.data.frame(crosspairs(tr.utm.ppp, op.ppp.cut, rmax=200)) ##
op.cut.nn$i_ID <- tr.utm$Tree_ID[op.cut.nn$i] ############################
op.cut.nn$j_ID <- op.cut$Palm_ID[op.cut.nn$j] ############################
op.cut.nn <- op.cut.nn[order(op.cut.nn$i_ID, op.cut.nn$d),] ##############
op.cut.min <- ddply(op.cut.nn, "i_ID", head, 1) ##########################
op.cut.min1 <- op.cut.min[,10:9] #########################################
names(op.cut.min1) <- c("Tree_ID", "dOPrem") #############################
tr.utm <- merge(tr.utm, op.cut.min1, by="Tree_ID") #######################
##########################################################################

# save file 
#write.csv(tr.utm,"C:/CRC990-B11/data/trees/tr.utm.csv")

############## All tree neighbors of all trees in 60 m distance
################################################################
tr.nn <- as.data.frame(closepairs(tr.utm.ppp, rmax=60)) #########
tr.nn$i_ID <- as.factor(tr.utm$Tree_ID[tr.nn$i]) ##########################
tr.nn$i_Sp <- tr.utm$Sp_scien[tr.nn$j] #########################
tr.nn$j_ID <- tr.utm$Tree_ID[tr.nn$j] ##########################
#tr.nn$j_hgt <- NA
tr.nn = tr.nn[c("d","i_ID","j_ID")]

# save file 
#write.csv(tr.nn,"C:/CRC990-B11/data/trees/tr.nn.csv")
