
####################################################################
####################################################################
###################                             ####################
###################      TREE GROWTH PAPER      ####################
###################                             ####################
####################################################################
####################################################################

# script to write table of tree performance (growth, mortality) 
# and structure (density, summed basal area) 
# at levels of: tree individual, tree species, and plot
# Clara Zemp, 2018


library(data.table)

#install.packages("NISTunits", dependencies = TRUE) # convert degree to Radian 
library(NISTunits)
NISTdegTOradian(180)

#deleting all objects
rm(list=ls())

# set working directory 
setwd("C:/CRC990-B11/data/trees")


# import data 
tree.2015        <- fread("C:/CRC990-B11/Data/trees/B11_tree_Anne2015_20190114.csv")
tree.2016        <- fread("C:/CRC990-B11/Data/trees/B11_tree_Anne2016_20180730.csv")
tree.2017        <- fread("C:/CRC990-B11/Data/trees/B11_tree_Andi2017_20180730.csv")
tree.2018        <- fread("C:/CRC990-B11/Data/trees/B11_tree_Andi2018_20190119.csv")

infoplots   <- fread("C:/CRC990-B11/Experiment/B11plot_with_controlplots_201705.csv")

# convert data to numeric 
tree.2015$Height_total <- as.numeric(as.character(tree.2015$Height_total))
tree.2016$Height_total <- as.numeric(as.character(tree.2016$Height_total))
tree.2017$Height_total <- as.numeric(as.character(tree.2017$Height_total))

tree.2017$Height_vertical <- as.numeric(as.character(tree.2017$Height_vertical))
tree.2018$Height_vertical <- as.numeric(as.character(tree.2018$Height_vertical))

tree.2018$Inclin <- as.numeric(as.character(tree.2018$Inclin))
tree.2018$TreeID <- as.numeric(as.character(tree.2018$TreeID))

tree.2015$Diameter <- as.numeric(as.character(tree.2015$Diameter))
tree.2016$Diameter <- as.numeric(as.character(tree.2016$Diameter))
tree.2017$Diameter <- as.numeric(as.character(tree.2017$Diameter))
tree.2018$Diameter <- as.numeric(as.character(tree.2018$Diameter))

tree.2015$Survival <- as.numeric(as.character(tree.2015$Survival))
tree.2016$Survival <- as.numeric(as.character(tree.2016$Survival))
tree.2017$Survival <- as.numeric(as.character(tree.2017$Survival))
tree.2018$Survival <- as.numeric(as.character(tree.2018$Survival))

# get plot area in m^2 
infoplots[,Size_squared:=Size^2]

# get diversity catergory (mono-species or multi-species plots) 
infoplots$Div <- NA
infoplots[DivLev==1]$Div <- FALSE
infoplots[DivLev>1]$Div <- TRUE
infoplots$Div <- as.numeric(infoplots$Div)

# get basal area (cm ^2)
tree.2015[,BA:=pi*(Diameter/2)^2]
tree.2016[,BA:=pi*(Diameter/2)^2]
tree.2017[,BA:=pi*(Diameter/2)^2]
tree.2018[,BA:=pi*(Diameter/2)^2]

# calculate total height from inclination and vertical height (experimental)

#tree.2018$Inclin <- NISTdegTOradian(tree.2018$Inclin) # degree to radian 
#tree.2018$Height_total <- tree.2018$Height_vertical/sin(tree.2018$Inclin)

################################################
# Merge data

tree.merge.15.16 = merge(tree.2015[,.(TreeID,Diameter,Height_total,Survival,BA)],
                         tree.2016[,.(TreeID,Diameter,Height_total,Survival,BA)]
                         ,by="TreeID",all=FALSE)

#,suffixes = c(".2015",".2016") # this leads to mistakes ! Better rename the columns

# rename 
names(tree.merge.15.16)[names(tree.merge.15.16) == "Diameter.x"] <- "Diameter.2015"
names(tree.merge.15.16)[names(tree.merge.15.16) == "Diameter.y"] <- "Diameter.2016"
names(tree.merge.15.16)[names(tree.merge.15.16) == "Height_total.x"] <- "Height.2015"
names(tree.merge.15.16)[names(tree.merge.15.16) == "Height_total.y"] <- "Height.2016"
names(tree.merge.15.16)[names(tree.merge.15.16) == "Survival.x"] <- "Survival.2015"
names(tree.merge.15.16)[names(tree.merge.15.16) == "Survival.y"] <- "Survival.2016"
names(tree.merge.15.16)[names(tree.merge.15.16) == "BA.x"] <- "BA.2015"
names(tree.merge.15.16)[names(tree.merge.15.16) == "BA.y"] <- "BA.2016"


tree.merge.17.18 = merge(tree.2017[,.(TreeID,Diameter,Height_vertical,Survival,BA)],
                         tree.2018[,.(TreeID,Diameter,Height_vertical,Survival,BA)]
                         ,by="TreeID",all=FALSE)

# rename 
names(tree.merge.17.18)[names(tree.merge.17.18) == "Diameter.x"] <- "Diameter.2017"
names(tree.merge.17.18)[names(tree.merge.17.18) == "Diameter.y"] <- "Diameter.2018"
names(tree.merge.17.18)[names(tree.merge.17.18) == "Height_vertical.x"] <- "Height.2017"
names(tree.merge.17.18)[names(tree.merge.17.18) == "Height_vertical.y"] <- "Height.2018"
names(tree.merge.17.18)[names(tree.merge.17.18) == "Survival.x"] <- "Survival.2017"
names(tree.merge.17.18)[names(tree.merge.17.18) == "Survival.y"] <- "Survival.2018"
names(tree.merge.17.18)[names(tree.merge.17.18) == "BA.x"] <- "BA.2017"
names(tree.merge.17.18)[names(tree.merge.17.18) == "BA.y"] <- "BA.2018"

tree.merge = merge(tree.merge.15.16,tree.merge.17.18,by="TreeID")


# include species and plots information 
tree.sp = merge(tree.merge,tree.2015[,.(TreeID,PlotID,Species)],by="TreeID")
tree.plots = merge (tree.sp,infoplots,by="PlotID")

# check data fit (should be NULL) - optional
# setdiff(tree.merge2$Species.2016, tree.merge2$Species.2017) 
# setdiff(tree.merge2$Species.2016, tree.merge2$Species) 

# save the file 

#write.csv(tree.merge, file = "B11.tree.merge.csv",row.names=TRUE, na="")
#write.csv(tree.plots, file = "B11.tree.plots.csv",row.names=TRUE, na="")


#####################################################################################
# -- get tree mortality probability for each tree (at individual level)
# 1 if dead during the study period
# 0 if still alive during the study period

Mort.tree = tree.sp[,.(mort_15.16 = Survival.2015-Survival.2016,
                          mort_16.17 = Survival.2016-Survival.2017,
                          mort_17.18 = Survival.2017-Survival.2018,
                          mort_16.18 = Survival.2016-Survival.2018,
                          mort_15.18 = Survival.2015-Survival.2018)
                       ,.(TreeID,PlotID,Species)]

# check inconsistancies in data
Mort.tree[which(Mort.tree$mort_15.16==-1)]
Mort.tree[which(Mort.tree$mort_16.17==-1)]
Mort.tree[which(Mort.tree$mort_17.18==-1)]

# NA if already dead at the begining of the study period
ind = which(tree.2015$Survival==0) # carefull not Tree ID (just matrix index)
Mort.tree$mort_15.16[ind] <- NA
Mort.tree$mort_15.18[ind] <- NA

ind = which(tree.2016$Survival==0) # carefull not Tree ID (just matrix index)
Mort.tree$mort_16.17[ind] <- NA

ind = which(tree.2017$Survival==0) # carefull not Tree ID (just matrix index)
Mort.tree$mort_17.18[ind] <- NA

#write.csv(Mort.tree, file = "Mort.tree.csv",row.names=TRUE, na="") 


#####################################################################################
# Get stem biomass

# -- create a new clolumn for wood density (Wood density (g/cm^3), oven dry mass/fresh volume)
tree.plots$WD <- 0 # create empty colum 
tree.plots[Species=="sungkai"]$WD <- 0.57
tree.plots[Species=="Jengkol"]$WD <- 0.36
tree.plots[Species=="petai"]$WD <- 0.395
tree.plots[Species=="meranti"]$WD <- 0.44
tree.plots[Species=="jelutung"]$WD <- 0.336
tree.plots[Species=="durian"]$WD <- 0.516

# -- get biomass in g = basal area (in cm^2) x height (convertion in cm) x wood density (g/cm^3)
tree.plots = tree.plots[,. (Biomass.2015 = BA.2015 * Height.2015*100 * WD
        ,Biomass.2016 = BA.2016 * Height.2016*100 * WD
        ,Biomass.2017 = BA.2017 * Height.2017*100 * WD
        ,Biomass.2018 = BA.2018 * Height.2018*100 * WD)
  ,.(TreeID, Species, PlotID, Diameter.2015, Height.2015, Survival.2015, BA.2015,
     Diameter.2016, Height.2016, Survival.2016,   BA.2016,
     Diameter.2017, Height.2017, Survival.2017,  BA.2017,
     Diameter.2018, Height.2018, Survival.2018,  BA.2018,
     Lat, Long, Size, DivLev, Composition, Nb_planted_trees, Size_squared, Div)]


# save files 
#write.csv(tree.plots, file = "B11.tree.plots.csv",row.names=TRUE, na="") 

#####################################################################################
# Get tree growth at tree level 

# --- relative growth rate  
RGR.tree = tree.plots[,.(Diam_inc_15.16 = log(Diameter.2016)-log(Diameter.2015)
                         ,Diam_inc_16.17 = log(Diameter.2017)-log(Diameter.2016)
                         ,Diam_inc_17.18 = log(Diameter.2018)-log(Diameter.2017)
                         ,BA_inc_15.16 = log(BA.2016)-log(BA.2015)
                         ,BA_inc_16.17 = log(BA.2017)-log(BA.2016)
                         ,BA_inc_17.18 = log(BA.2018)-log(BA.2017)
                         ,Height_inc_15.16 = log(Height.2016)-log(Height.2015)
                         ,Height_inc_16.17 = log(Height.2017)-log(Height.2016)
                         ,Height_inc_17.18 = log(Height.2018)-log(Height.2017)
                         ,Biomass_inc_15.16 = log(Biomass.2016)-log(Biomass.2015)
                         ,Biomass_inc_16.17 = log(Biomass.2017)-log(Biomass.2016)
                         ,Biomass_inc_17.18 = log(Biomass.2018)-log(Biomass.2017)
                         ,Diam_inc_15.18 = (log(Diameter.2018)-log(Diameter.2015))/(2018-2015)
                         ,BA_inc_15.18 = (log(BA.2018)-log(BA.2015))/(2018-2015)
                         ,Height_inc_15.18 = (log(Height.2018)-log(Height.2015))/(2018-2015)
                         ,Biomass_inc_15.18 = (log(Biomass.2018)-log(Biomass.2015))/(2018-2015)
                         ,Diam_inc_16.18 = (log(Diameter.2018)-log(Diameter.2016))/(2018-2016)
                         ,BA_inc_16.18 = (log(BA.2018)-log(BA.2016))/(2018-2016)
                         ,Height_inc_16.18 = (log(Height.2018)-log(Height.2016))/(2018-2016)
                         ,Biomass_inc_16.18 = (log(Biomass.2018)-log(Biomass.2016))/(2018-2016))
                      ,.(TreeID,Species,PlotID)]

# # --- absolute growth rate 
AGR.tree = tree.plots[,.(Diam_inc_15.16 = Diameter.2016-Diameter.2015
                         ,Diam_inc_16.17 = Diameter.2017-Diameter.2016
                         ,Diam_inc_17.18 = Diameter.2018-Diameter.2017
                         ,BA_inc_15.16 = BA.2016-BA.2015
                         ,BA_inc_16.17 = BA.2017-BA.2016
                         ,BA_inc_17.18 = BA.2018-BA.2017
                         ,Height_inc_15.16 = Height.2016-Height.2015
                         ,Height_inc_16.17 = Height.2017-Height.2016
                         ,Height_inc_17.18 = Height.2018-Height.2017
                      ,Biomass_inc_15.16 = Biomass.2016-Biomass.2015
                      ,Biomass_inc_16.17 = Biomass.2017-Biomass.2016
                      ,Biomass_inc_17.18 = Biomass.2018-Biomass.2017
                      ,Biomass_inc_15.18 = (Biomass.2018-Biomass.2015)/(2018-2015)
                      ,Biomass_inc_16.18 = (Biomass.2018-Biomass.2016)/(2018-2016)
                      ,Diam_inc_15.18 = (Diameter.2018-Diameter.2015)/(2018-2015)
                         ,BA_inc_15.18 = (BA.2018-BA.2015)/(2018-2015)
                         ,Height_inc_15.18 = (Height.2018-Height.2015)/(2018-2015)
                         ,Diam_inc_16.18 = (Diameter.2018-Diameter.2016)/(2018-2016)
                         ,BA_inc_16.18 = (BA.2018-BA.2016)/(2018-2016)
                         ,Height_inc_16.18 = (Height.2018-Height.2015)/(2018-2015))
                      ,.(TreeID,Species,PlotID)]


#####################################################################################
# visualize the data 

# cleaveland plots 
x11()
plot(AGR.tree$TreeID, AGR.tree$Height_inc_15.18 )
x11()
plot(AGR.tree$TreeID, AGR.tree$Diam_inc_15.18 )

# x11()
# #plot(RGR.tree$TreeID, RGR.tree$BA_inc_16.17 )
# plot(AGR.tree$TreeID, AGR.tree$BA_inc_16.17 )
# 
# x11()
# #plot(RGR.tree$TreeID, RGR.tree$BA_inc_17.18 )
# plot(AGR.tree$TreeID, AGR.tree$BA_inc_17.18 )

x11()
plot(tree.plots$Diameter.2015, tree.plots$)
# plot(AGR.tree$TreeID, AGR.tree$BA_inc_17.18 )

#####################################################################################
# Deal with outliers 

# Build function to 
# exclude outsider values and set negative values to 0

# OPTION 2: outside an interval of plus/minus three absolute standard deviations around the median

Exclude_outliers2 = function(mydata){
  
  #print("criteria outliers: 3 standard deviations around the median")
  data_min = median(mydata,na.rm=T) - 3*sd(mydata,na.rm=T)
  data_max = median(mydata,na.rm=T) + 3*sd(mydata,na.rm=T)
  outliers = which(mydata > data_max | mydata < data_min ) 
  mydata[outliers] = NA 
  print(length(outliers))
  
  neg = which(mydata < 0)
  mydata[neg] <- 0 
  
  return(mydata)
}

# fixed outliers 
Exclude_outliers = function(mydata,outliers){
  
  if (is.finite(outliers)>0){
    mydata[outliers] = NA }
  
  neg = which(mydata < 0)
  mydata[neg] <- 0 
  
  return(mydata)
}


# exclude outliers 
Apply_exclude_outliers2 = function(G.tree){
  tree_sp = unique(tree.plots$Species)
  for (sp in tree_sp){
    print(sp)
    tree.plots[Species==sp]$Diameter.2015 <- Exclude_outliers2(tree.plots[Species==sp]$Diameter.2015)
    tree.plots[Species==sp]$Diameter.2016 <- Exclude_outliers2(tree.plots[Species==sp]$Diameter.2016)
    tree.plots[Species==sp]$Diameter.2017 <- Exclude_outliers2(tree.plots[Species==sp]$Diameter.2017)
    tree.plots[Species==sp]$Diameter.2018 <- Exclude_outliers2(tree.plots[Species==sp]$Diameter.2018)
    
    tree.plots[Species==sp]$BA.2015 <- Exclude_outliers2(tree.plots[Species==sp]$BA.2015)
    tree.plots[Species==sp]$BA.2016 <- Exclude_outliers2(tree.plots[Species==sp]$BA.2016)
    tree.plots[Species==sp]$BA.2017 <- Exclude_outliers2(tree.plots[Species==sp]$BA.2017)
    tree.plots[Species==sp]$BA.2018 <- Exclude_outliers2(tree.plots[Species==sp]$BA.2018)
    
    tree.plots[Species==sp]$Height_total.2015 <- Exclude_outliers2(tree.plots[Species==sp]$Height_total.2015)
    tree.plots[Species==sp]$Height_total.2016 <- Exclude_outliers2(tree.plots[Species==sp]$Height_total.2016)
    tree.plots[Species==sp]$Height_vertical.2017 <- Exclude_outliers2(tree.plots[Species==sp]$Height_vertical.2017)
    tree.plots[Species==sp]$Height_vertical.2018 <- Exclude_outliers2(tree.plots[Species==sp]$Height_vertical.2018)
    
    tree.plots[Species==sp]$Biomass.2015 <- Exclude_outliers2(tree.plots[Species==sp]$Biomass.2015)
    tree.plots[Species==sp]$Biomass.2016 <- Exclude_outliers2(tree.plots[Species==sp]$Biomass.2016)
    tree.plots[Species==sp]$Biomass.2017 <- Exclude_outliers2(tree.plots[Species==sp]$Biomass.2017)
    tree.plots[Species==sp]$Biomass.2018 <- Exclude_outliers2(tree.plots[Species==sp]$Biomass.2018)
    
  }
  return(tree.plots)
}

#tree.plots = Apply_exclude_outliers2(tree.plots)


# detect outliers
# = which(RGR.tree$BA_inc_15.18>2) # tree ID 2831 (inconsistancy BA and height in 2015 compared to the other years)

# apply the function to the dataframe
# per species 
# OPTION 21: 3 std deviation around median 

Apply_exclude_outliers2 = function(G.tree){
  tree_sp = unique(G.tree$Species)
  for (sp in tree_sp){
    print(sp)
    G.tree[Species==sp]$Diam_inc_15.18 <- Exclude_outliers2(G.tree[Species==sp]$Diam_inc_15.18)
    G.tree[Species==sp]$BA_inc_15.18 <- Exclude_outliers2(G.tree[Species==sp]$BA_inc_15.18)
    G.tree[Species==sp]$Height_inc_15.18 <- Exclude_outliers2(G.tree[Species==sp]$Height_inc_15.18)
    G.tree[Species==sp]$Biomass_inc_15.18 <- Exclude_outliers2(G.tree[Species==sp]$Biomass_inc_15.18)
    
    G.tree[Species==sp]$Diam_inc_15.16 <- Exclude_outliers2(G.tree[Species==sp]$Diam_inc_15.16)
    G.tree[Species==sp]$BA_inc_15.16 <- Exclude_outliers2(G.tree[Species==sp]$BA_inc_15.16)
    G.tree[Species==sp]$Height_inc_15.16 <- Exclude_outliers2(G.tree[Species==sp]$Height_inc_15.16)
    G.tree[Species==sp]$Biomass_inc_15.16 <- Exclude_outliers2(G.tree[Species==sp]$Biomass_inc_15.16)
    
    G.tree[Species==sp]$Diam_inc_16.17 <- Exclude_outliers2(G.tree[Species==sp]$Diam_inc_16.17)
    G.tree[Species==sp]$BA_inc_16.17 <- Exclude_outliers2(G.tree[Species==sp]$BA_inc_16.17)
    G.tree[Species==sp]$Height_inc_16.17 <- Exclude_outliers2(G.tree[Species==sp]$Height_inc_16.17)
    G.tree[Species==sp]$Biomass_inc_16.17 <- Exclude_outliers2(G.tree[Species==sp]$Biomass_inc_16.17)
    
    G.tree[Species==sp]$Diam_inc_17.18 <- Exclude_outliers2(G.tree[Species==sp]$Diam_inc_17.18)
    G.tree[Species==sp]$BA_inc_17.18 <- Exclude_outliers2(G.tree[Species==sp]$BA_inc_17.18)
    G.tree[Species==sp]$Height_inc_17.18 <- Exclude_outliers2(G.tree[Species==sp]$Height_inc_17.18)
    G.tree[Species==sp]$Biomass_inc_17.18 <- Exclude_outliers2(G.tree[Species==sp]$Biomass_inc_17.18)
    
    G.tree[Species==sp]$Diam_inc_16.18 <- Exclude_outliers2(G.tree[Species==sp]$Diam_inc_16.18)
    G.tree[Species==sp]$BA_inc_16.18 <- Exclude_outliers2(G.tree[Species==sp]$BA_inc_16.18)
    G.tree[Species==sp]$Height_inc_16.18 <- Exclude_outliers2(G.tree[Species==sp]$Height_inc_16.18)
    G.tree[Species==sp]$Biomass_inc_16.18 <- Exclude_outliers2(G.tree[Species==sp]$Biomass_inc_16.18)
    
  }
  return(G.tree)
}

# OPTION 1: exclude given outliers 
# apply the function to the dataframe
# Apply_exclude_outliers = function(G.tree,outliers){
#   
#   print("nb of outliers excluded: ") 
#   print(length(outliers))
#   
#   G.tree$Diam_inc_15.18 <- Exclude_outliers(G.tree$Diam_inc_15.18,outliers)
#   G.tree$BA_inc_15.18 <- Exclude_outliers(G.tree$BA_inc_16.18,outliers)
#   G.tree$Height_inc_15.18 <- Exclude_outliers(G.tree$Height_inc_15.18,outliers)
#   
#   G.tree$Diam_inc_15.16 <- Exclude_outliers(G.tree$Diam_inc_15.16,outliers)
#   G.tree$BA_inc_15.16 <- Exclude_outliers(G.tree$BA_inc_15.16,outliers)
#   G.tree$Height_inc_15.16 <- Exclude_outliers(G.tree$Height_inc_15.16,outliers)
#   
#   G.tree$Diam_inc_16.17 <- Exclude_outliers(G.tree$Diam_inc_16.17,outliers)
#   G.tree$BA_inc_16.17 <- Exclude_outliers(G.tree$BA_inc_16.17,outliers)
#   G.tree$Height_inc_16.17 <- Exclude_outliers(G.tree$Height_inc_16.17,outliers)
#   
#   G.tree$Diam_inc_17.18 <- Exclude_outliers(G.tree$Diam_inc_17.18,outliers)
#   G.tree$BA_inc_17.18 <- Exclude_outliers(G.tree$BA_inc_17.18,outliers)
#   G.tree$Height_inc_17.18 <- Exclude_outliers(G.tree$Height_inc_17.18,outliers)
#   
#   G.tree$Diam_inc_16.18 <- Exclude_outliers(G.tree$Diam_inc_16.18,outliers)
#   G.tree$BA_inc_16.18 <- Exclude_outliers(G.tree$BA_inc_16.18,outliers)
#   G.tree$Height_inc_16.18 <- Exclude_outliers(G.tree$Height_inc_16.18,outliers)
#   
#   return(G.tree)
# }
#option 1
#RGR.tree <- Apply_exclude_outliers(RGR.tree,outliers) 
#AGR.tree <- Apply_exclude_outliers(AGR.tree,outliers) 

# option 2 (+- 3 absolute standard deviations around the median)
RGR.tree <- Apply_exclude_outliers2(RGR.tree) 
AGR.tree <- Apply_exclude_outliers2(AGR.tree) 

# save files 
#write.csv(RGR.tree, file = "RGR.tree.csv",row.names=TRUE, na="") 
#write.csv(AGR.tree, file = "AGR.tree.csv",row.names=TRUE, na="") 


#####################################################################################
# Get diversity indices for planted trees at plot level

species_name = unique(tree.plots$Species) # get list of species name

stat.tree2018 = tree.plots[,.(Nb_trees_alive=sum(Survival.2018==1))  # number of trees alive per plot in 2015
                           ,.(PlotID)]

df = data.frame(matrix(rnorm(6*52), nrow=52))  # create a new empty data frame
df = df[FALSE,]
colnames(df) <- c(species_name)

for (i in 1:length(species_name)){
  ind = which((tree.plots$Species==species_name[i])&(tree.plots$Survival.2018==1)) # index of living trees from species i 
  Ti = tree.plots[ind] 
  Ni = Ti[,.(Nb_trees_i = length(unique(TreeID))),.(PlotID)] # number of living trees that belong to species i per plot
  #Di = Ti[,.(D_trees_i = mean(Diameter,na.rm=TRUE)),.(PlotID)] # mean diameter of living trees that belong to species i per plot
  
  Ni.merge = merge(Ni,stat.tree2018,by.x="PlotID",by.y="PlotID")
 # Di.merge = merge(Di,stat.tree2018,by.x="PlotID",by.y="PlotID")
  
  Pi = Ni.merge[,.(h_i=(Nb_trees_i/Nb_trees_alive)*log(Nb_trees_i/Nb_trees_alive)) # term for shannon diversity index associated with species i
                ,.(PlotID)] 
  #Pi = Di.merge[,.(h_i=(D_trees_i/Mean_diameter)*log(D_trees_i/Mean_diameter)) # term for shannon diversity index associated with species i
  #       ,.(PlotID)] 
  df[Pi$PlotID,i] <- Pi$h_i
}

H = -rowSums(df, na.rm=T) # shannon diversity index 
e = exp(H) # effective species richness (see Erskine et al. 2006, Forest Ecology and Management)
R = rowSums(!is.na(df)) # Species Richness (number of species from trees alive)
R.fac = as.factor(R) # species richness as a factor 

# enter the data in a dataframe
div = data.frame(matrix(rnorm(5*52), nrow=52))  # create a new empty data frame
colnames(div) <- c("PlotID","H","e","R","R.fac")
div[,1]=seq(1,52)
div[,2]=H
div[,3]=e
div[,4]=R
div[,5]=R.fac

# set to NA (not applicable) to e and H values for plots with no remaining trees
ind_notree = which(div$R==0) 
div[R==0,c('e','H')] <- NA

# save the file 
#write.csv(div, file = "div_tree_B11_201801.v2.csv",row.names=TRUE, na="")




#####################################################################################
#-- get tree structural variables at plot level (tree density, sum basal area) for each year 

str.plot = tree.plots[,.(Nb_trees_alive.2015=sum(Survival.2015,na.rm=TRUE) # number of trees alive per plot in 2015
                             ,Nb_trees_alive.2016=sum(Survival.2016,na.rm=TRUE)
                             ,Nb_trees_alive.2017=sum(Survival.2017,na.rm=TRUE)
                             ,Nb_trees_alive.2018=sum(Survival.2018,na.rm=TRUE)
                             ,SBA.2015 = sum(BA.2015,na.rm=TRUE) # sum basal area per plot in 2015 (cm^2)
                             ,SBA.2016 = sum(BA.2016,na.rm=TRUE)
                             ,SBA.2017 = sum(BA.2017,na.rm=TRUE)
                             ,SBA.2018 = sum(BA.2018,na.rm=TRUE)
                             ,SBiomass.2015 = sum(Biomass.2015,na.rm=TRUE) # sum basal area per plot in 2015 (cm^2)
                             ,SBiomass.2016 = sum(Biomass.2016,na.rm=TRUE)
                             ,SBiomass.2017 = sum(Biomass.2017,na.rm=TRUE)
                             ,SBiomass.2018 = sum(Biomass.2018,na.rm=TRUE)
                             ,AvgBA.2015 = mean(BA.2015,na.rm=TRUE) # average basal area per plot in 2015 (cm^2)
                             ,AvgBA.2016 = mean(BA.2016,na.rm=TRUE)
                             ,AvgBA.2017 = mean(BA.2017,na.rm=TRUE)
                             ,AvgBA.2018 = mean(BA.2018,na.rm=TRUE))
                          ,.(PlotID,Size_squared,DivLev,Composition,Nb_planted_trees)]

# scale to plot size (in m^2)
str.plot = str.plot[,.(dens.2015 =(Nb_trees_alive.2015)/(Size_squared*0.0001) # tree density  (N trees / ha)
                              ,dens.2016 =(Nb_trees_alive.2016)/(Size_squared*0.0001)
                              ,dens.2017 =(Nb_trees_alive.2017)/(Size_squared*0.0001)
                              ,dens.2018 =(Nb_trees_alive.2018)/(Size_squared*0.0001)
                              ,dens.ini =(Nb_planted_trees)/(Size_squared*0.0001) # initial tree density  (N trees / ha)
                              ,SBA.2015 = SBA.2015/(Size_squared) # sum basal area (cm^2 / m^2 = m^2 / ha)
                              ,SBA.2016 = SBA.2016/(Size_squared) 
                              ,SBA.2017 = SBA.2017/(Size_squared) 
                              ,SBA.2018 = SBA.2018/(Size_squared) 
                              ,Biomass.2015 = SBiomass.2015/(Size_squared)*0.01 # biomass ( g / m^2 * 0.01 = t / ha)
                              ,Biomass.2016 = SBiomass.2016/(Size_squared) *0.01
                              ,Biomass.2017 = SBiomass.2017/(Size_squared) *0.01
                              ,Biomass.2018 = SBiomass.2018/(Size_squared) *0.01)
                           ,.(PlotID,AvgBA.2015,AvgBA.2016,AvgBA.2017,AvgBA.2018)]

#write.csv(str.plot, file = "str.plot.csv",row.names=TRUE, na="")

# for each species

str.plot.sp0 = tree.plots[,.(Nb_trees_alive.2015=sum(Survival.2015,na.rm=TRUE) # number of trees alive per plot in 2015
                              ,Nb_trees_alive.2016=sum(Survival.2016,na.rm=TRUE)
                              ,Nb_trees_alive.2017=sum(Survival.2017,na.rm=TRUE)
                              ,Nb_trees_alive.2018=sum(Survival.2018,na.rm=TRUE)
                           ,SBA.2015 = sum(BA.2015,na.rm=TRUE) # sum basal area per plot in 2015 (cm^2)
                           ,SBA.2016 = sum(BA.2016,na.rm=TRUE)
                           ,SBA.2017 = sum(BA.2017,na.rm=TRUE)
                           ,SBA.2018 = sum(BA.2018,na.rm=TRUE)
                           ,SBiomass.2015 = sum(Biomass.2015,na.rm=TRUE) # sum basal area per plot in 2015 (cm^2)
                           ,SBiomass.2016 = sum(Biomass.2016,na.rm=TRUE)
                           ,SBiomass.2017 = sum(Biomass.2017,na.rm=TRUE)
                           ,SBiomass.2018 = sum(Biomass.2018,na.rm=TRUE)
                        ,AvgBA.2015 = mean(BA.2015,na.rm=TRUE) # average basal area per plot in 2015 (cm^2)
                        ,AvgBA.2016 = mean(BA.2016,na.rm=TRUE)
                        ,AvgBA.2017 = mean(BA.2017,na.rm=TRUE)
                        ,AvgBA.2018 = mean(BA.2018,na.rm=TRUE))
                           ,.(PlotID,Size_squared,DivLev,Composition,Nb_planted_trees,Species)]

# scale to plot size (in m^2)
str.plot.sp = str.plot.sp0[,.(dens.2015 =(Nb_trees_alive.2015)/(Size_squared*0.0001) # tree density  (N trees / ha)
                           ,dens.2016 =(Nb_trees_alive.2016)/(Size_squared*0.0001)
                           ,dens.2017 =(Nb_trees_alive.2017)/(Size_squared*0.0001)
                           ,dens.2018 =(Nb_trees_alive.2018)/(Size_squared*0.0001)
                           ,dens.ini =(Nb_planted_trees)/(Size_squared*0.0001) # initial tree density  (N trees / ha)
                          ,SBA.2015 = SBA.2015/(Size_squared) # sum basal area (cm^2 / m^2 = m^2 / ha)
                          ,SBA.2016 = SBA.2016/(Size_squared) 
                          ,SBA.2017 = SBA.2017/(Size_squared) 
                          ,SBA.2018 = SBA.2018/(Size_squared) 
                          ,Biomass.2015 = SBiomass.2015/(Size_squared)*0.01 # biomass ( g / m^2 * 0.01 = t / ha)
                          ,Biomass.2016 = SBiomass.2016/(Size_squared) *0.01
                          ,Biomass.2017 = SBiomass.2017/(Size_squared) *0.01
                          ,Biomass.2018 = SBiomass.2018/(Size_squared) *0.01)
                                 ,.(PlotID,Size_squared,DivLev,Composition,
                                    AvgBA.2015,AvgBA.2016,AvgBA.2017,AvgBA.2018,Species)]

# merge with plot-level tree diversity
#str.plot.sp = merge(str.plot.sp,div,by="PlotID")

#write.csv(stat.tree.plots, file = "stat.tree.plots.csv",row.names=TRUE, na="")

#####################################################################################
# statistics per species and diversity level 


# -- max growth rate per species 
AGR.tree[,.(maxAGR=quantile(Biomass_inc_15.18,0.9,na.rm=TRUE)) 
         ,.(Species)]



diam_multi = tree.plots[DivLev>1,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                                   ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                                   ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                                   ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                        ,.(Species)]

diam_DivLev2 = tree.plots[DivLev==2,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                                   ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                                   ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                                   ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                       ,.(Species)]

diam_DivLev3 = tree.plots[DivLev==3,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                                   ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                                   ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                                   ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                       ,.(Species)]

diam_DivLev6 = tree.plots[DivLev==6,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                                      ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                                      ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                                      ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                          ,.(Species)]

diam_mono = tree.plots[DivLev==1,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                                   ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                                   ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                                   ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                       ,.(Species)]

diam_all = tree.plots[,.(v.2015 = mean(Diameter.2015,na.rm=TRUE)
                         ,v.2016 = mean(Diameter.2016,na.rm=TRUE)
                         ,v.2017 = mean(Diameter.2017,na.rm=TRUE)
                         ,v.2018 = mean(Diameter.2018,na.rm=TRUE))
                      ,.(Species)]


# diam_all = tree.plots[,.(v.2015 = sd(Diameter.2015,na.rm=TRUE)
#                                    ,v.2016 = sd(Diameter.2016,na.rm=TRUE)
#                                    ,v.2017 = sd(Diameter.2017,na.rm=TRUE)
#                                    ,v.2018 = sd(Diameter.2018,na.rm=TRUE))
#                        ,.(Species)]

# -- tree basa area 
BA_multi = tree.plots[DivLev>1,.(v.2015 = mean(BA.2015,na.rm=TRUE)
                                   ,v.2016 = mean(BA.2016,na.rm=TRUE)
                                   ,v.2017 = mean(BA.2017,na.rm=TRUE)
                                   ,v.2018 = mean(BA.2018,na.rm=TRUE))
                        ,.(Species)]


BA_DivLev2 = tree.plots[DivLev==2,.(v.2015 = mean(BA.2015,na.rm=TRUE)
                                 ,v.2016 = mean(BA.2016,na.rm=TRUE)
                                 ,v.2017 = mean(BA.2017,na.rm=TRUE)
                                 ,v.2018 = mean(BA.2018,na.rm=TRUE))
                      ,.(Species)]

BA_DivLev3 = tree.plots[DivLev==3,.(v.2015 = mean(BA.2015,na.rm=TRUE)
                                    ,v.2016 = mean(BA.2016,na.rm=TRUE)
                                    ,v.2017 = mean(BA.2017,na.rm=TRUE)
                                    ,v.2018 = mean(BA.2018,na.rm=TRUE))
                        ,.(Species)]

BA_DivLev6 = tree.plots[DivLev==6,.(v.2015 = mean(BA.2015,na.rm=TRUE)
                                    ,v.2016 = mean(BA.2016,na.rm=TRUE)
                                    ,v.2017 = mean(BA.2017,na.rm=TRUE)
                                    ,v.2018 = mean(BA.2018,na.rm=TRUE))
                        ,.(Species)]


BA_mono = tree.plots[DivLev==1,.(v.2015 = mean(BA.2015,na.rm=TRUE)
                                   ,v.2016 = mean(BA.2016,na.rm=TRUE)
                                   ,v.2017 = mean(BA.2017,na.rm=TRUE)
                                   ,v.2018 = mean(BA.2018,na.rm=TRUE))
                       ,.(Species)]

# -- tree height 
height_multi = tree.plots[DivLev>1,.(v.2015 = mean(Height.2015,na.rm=TRUE)
                                     ,v.2016 = mean(Height.2016,na.rm=TRUE)
                                     ,v.2017 = mean(Height.2017,na.rm=TRUE)
                                     ,v.2018 = mean(Height.2018,na.rm=TRUE))
                          ,.(Species)]

height_DivLev2 = tree.plots[DivLev==2,.(v.2015 = mean(Height.2015,na.rm=TRUE)
                                     ,v.2016 = mean(Height.2016,na.rm=TRUE)
                                     ,v.2017 = mean(Height.2017,na.rm=TRUE)
                                     ,v.2018 = mean(Height.2018,na.rm=TRUE))
                          ,.(Species)]

height_DivLev3 = tree.plots[DivLev==3,.(v.2015 = mean(Height.2015,na.rm=TRUE)
                                     ,v.2016 = mean(Height.2016,na.rm=TRUE)
                                     ,v.2017 = mean(Height.2017,na.rm=TRUE)
                                     ,v.2018 = mean(Height.2018,na.rm=TRUE))
                          ,.(Species)]

height_DivLev6 = tree.plots[DivLev==6,.(v.2015 = mean(Height.2015,na.rm=TRUE)
                                     ,v.2016 = mean(Height.2016,na.rm=TRUE)
                                     ,v.2017 = mean(Height.2017,na.rm=TRUE)
                                     ,v.2018 = mean(Height.2018,na.rm=TRUE))
                          ,.(Species)]

height_mono = tree.plots[DivLev==1,.(v.2015 = mean(Height.2015,na.rm=TRUE)
                                     ,v.2016 = mean(Height.2016,na.rm=TRUE)
                                     ,v.2017 = mean(Height.2017,na.rm=TRUE)
                                     ,v.2018 = mean(Height.2018,na.rm=TRUE))
                         ,.(Species)]


size_all = tree.plots[,.(sdH.2015 = sd(Height.2015,na.rm=TRUE)
                                     ,sdH.2016 = sd(Height.2016,na.rm=TRUE)
                                     ,sdH.2017 = sd(Height.2017,na.rm=TRUE)
                                     ,sdH.2018 = sd(Height.2018,na.rm=TRUE)
                        ,mH.2015 = mean(Height.2015,na.rm=TRUE)
                                    ,mH.2016 = mean(Height.2016,na.rm=TRUE)
                                    ,mH.2017 = mean(Height.2017,na.rm=TRUE)
                                    ,mH.2018 = mean(Height.2018,na.rm=TRUE)
                        ,sdBA.2015 = sd(BA.2015,na.rm=TRUE)
                          ,sdBA.2016 = sd(BA.2016,na.rm=TRUE)
                          ,sdBA.2017 = sd(BA.2017,na.rm=TRUE)
                          ,sdBA.2018 = sd(BA.2018,na.rm=TRUE)
                          ,mBA.2015 = mean(BA.2015,na.rm=TRUE)
                          ,mBA.2016 = mean(BA.2016,na.rm=TRUE)
                          ,mBA.2017 = mean(BA.2017,na.rm=TRUE)
                          ,mBA.2018 = mean(BA.2018,na.rm=TRUE))
                         ,.(Species)]

#####################################################################################
# -- get tree survival probability for each species ( and per plot size and diversity level )
# (for bootstrapping)


Nmono = tree.plots[DivLev==1, list(Freq = .N), by = Species] # total number of trees planted in mono-species plots


# -- tree survival probability per species (optional)

survival0 = tree.plots[,.(Nsurv.2015 = sum(Survival.2015) # number of trees alive in 2015
                          ,Nsurv.2016 = sum(Survival.2016)
                          ,Nsurv.2017 = sum(Survival.2017)
                          ,Nsurv.2018 = sum(Survival.2018)
                          ,Nini = length(Survival.2015)) # initial number of planted tree
                       ,.(Species)]

survival = survival0[,.(surv.2016 = sum(Nsurv.2016)/sum(Nini)
                       ,surv.2017 = sum(Nsurv.2017)/sum(Nini)
                       ,surv.2018 = sum(Nsurv.2018)/sum(Nini))
                       ,.(Species)]

# -- tree survival probability per diversity level and per species

survival0 = tree.plots[,.(Nsurv.2015 = sum(Survival.2015)# number of trees alive in 2015
                          ,Nsurv.2016 = sum(Survival.2016)
                          ,Nsurv.2017 = sum(Survival.2017)
                          ,Nsurv.2018 = sum(Survival.2018)
                          ,Nini = length(Survival.2015)) # initial number of planted tree
                       ,.(Species,DivLev)]


survival.DivLev = survival0[,.(surv.2015 = sum(Nsurv.2015)/sum(Nini)
                               ,surv.2016 = sum(Nsurv.2016)/sum(Nini)
                               ,surv.2017 = sum(Nsurv.2017)/sum(Nini)
                               ,surv.2018 = sum(Nsurv.2018)/sum(Nini))
                          ,.(Species,DivLev)]

survival_mono = survival.DivLev[DivLev==1,.(v.2015 = surv.2015
                                            ,v.2016 = surv.2016
                                            ,v.2017 = surv.2017
                                            ,v.2018 = surv.2018)
                                ,.(Species)]

survival_multi = survival.DivLev[DivLev>1,.(v.2015 = mean(surv.2015,na.rm=TRUE)
                                        ,v.2016 = mean(surv.2016,na.rm=TRUE)
                                        ,v.2017 = mean(surv.2017,na.rm=TRUE)
                                        ,v.2018 = mean(surv.2018,na.rm=TRUE))
                            ,.(Species)]


# save the file for bootsrapping
#write.csv(survival.DivLev, file = "B11_survival.divlev.v2.csv",row.names=TRUE, na="")

# -- tree survival probability at plot level (diversity and size) and per species

survival0 = tree.plots[,.(Nsurv.2015 = sum(Survival.2015)# number of trees alive in 2015
                          ,Nsurv.2016 = sum(Survival.2016)
                          ,Nsurv.2017 = sum(Survival.2017)
                          ,Nsurv.2018 = sum(Survival.2018)
                          ,Nini = length(Survival.2015)) # initial number of planted tree
                       ,.(Species,DivLev,Div,Size,Size_squared,PlotID)]


survival.plots = survival0[,.(surv.2016 = sum(Nsurv.2016)/sum(Nini)
                               ,surv.2017 = sum(Nsurv.2017)/sum(Nini)
                               ,surv.2018 = sum(Nsurv.2018)/sum(Nini))
                            ,.(Species,DivLev,Div,Size,Size_squared,PlotID)]

# save the file for bootsrapping
#write.csv(survival.plots , file = "B11_survival.plots.csv",row.names=TRUE, na="")


#####################################################################################
## -- get total, annual and instanteneous mortality rates 
# per diversity, plot size and species 

mort = survival0[,.(tot.mort.15.18 = (100*sum(Nsurv.2015-Nsurv.2018))/(sum(Nsurv.2015))
                    ,ann.mort.15.18 = (100*sum(Nsurv.2015-Nsurv.2018))/((2018-2015)*sum(Nsurv.2015)) # annual mortality rate
                    ,inst.mort.15.18 = log(sum(Nsurv.2015)/sum(Nsurv.2018))/(2018-2015)) # instantaneous mortality rate (see Potvin et al., Ecology Letter, 2008)
                 ,.(Species,DivLev,PlotID)]

mort = survival0[,.(ann.mort.15.18 = (100*sum(Nsurv.2015-Nsurv.2018))/((2018-2015)*sum(Nsurv.2015)) # annual mortality rate
                    ,inst.mort.15.18 = log(sum(Nsurv.2015)/sum(Nsurv.2018))/(2018-2015)) # instantaneous mortality rate (see Potvin et al., Ecology Letter, 2008)
                          ,.(Species,DivLev,Size_squared)]

# mort[is.infinite(mort$inst.mort.15.18)]$inst.mort.15.18 <- 1.5 # attribute (arbitrary) high number for complete mortality 

